@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Array;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2016-12-10'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -102,6 +102,15 @@ sub get_args_from_array {
                     my @elems = splice(@$ary, $i);
                     if ($type eq 'array') {
                         $rargs->{$a} = \@elems;
+                    } elsif ($type eq 'hash') {
+                        $rargs->{$a} = {};
+                        for my $j (0..$#elems) {
+                            my $elem = $elems[$j];
+                            unless ($elem =~ /(.*?)=(.*)/) {
+                                return [400, "Invalid key=value pair in element #$j"];
+                            }
+                            $rargs->{$a}{$1} = $2;
+                        }
                     } else {
                         $rargs->{$a} = join " ", @elems;
                     }
@@ -135,7 +144,7 @@ Perinci::Sub::GetArgs::Array - Get subroutine arguments (%args) from array
 
 =head1 VERSION
 
-This document describes version 0.15 of Perinci::Sub::GetArgs::Array (from Perl distribution Perinci-Sub-GetArgs-Array), released on 2015-09-04.
+This document describes version 0.16 of Perinci::Sub::GetArgs::Array (from Perl distribution Perinci-Sub-GetArgs-Array), released on 2016-12-10.
 
 =head1 SYNOPSIS
 
@@ -174,6 +183,8 @@ then C<< get_args_from_array(array=E<gt>[2, 3], meta=E<gt>$meta) >> will produce
 
  [200, "OK", {a=>2, b=>3}]
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -211,17 +222,13 @@ that contains extra information.
 
 Return value:  (any)
 
-=head1 SEE ALSO
-
-L<Perinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-GetArgs-Array>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-GetArgs-Array>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-GetArgs-Array>.
 
 =head1 BUGS
 
@@ -231,13 +238,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
